﻿# $author = T. Butz, 
# $version = 2014.07.18
# $url = 'www.thorsten-butz.de'; $twitter = $adn = '@thorstenbutz'

<#
.SYNOPSIS
This scripts imports AD users from a CSV file.
 
.DESCRIPTION
The script creates an Active Directory OU (default=Frankfurt), if it does not exit, 
and imports users from one or more CSV files from a given folder path.
 
.EXAMPLE
.\Create-TBWeltmeister -folder 'c:\tmp' -city 'Berlin'
 
.PARAMETER folder
Path to the folder where the CSV file(s) exit.

.PARAMETER city
Name of the OU, where the AD users will be created. 

.NOTES
This script pays an homage to Germany's world soccer champions.

More about soccer and "Weltmeister":
http://de.wikipedia.org/wiki/Fu%C3%9Fball-Weltmeisterschaft_2014/Deutschland 
http://de.wikipedia.org/wiki/Fu%C3%9Fball-Weltmeisterschaft_1990/Deutschland 
http://de.wikipedia.org/wiki/Fu%C3%9Fball-Weltmeisterschaft_1974/Deutschland
http://de.wikipedia.org/wiki/Fu%C3%9Fball-Weltmeisterschaft_1954/Deutschland
 
.LINK
http://www.thorsten-butz.de/
https://github.com/thorstenbutz/
#>

[CmdletBinding()]

param (
  [Parameter(Mandatory=$true,ValueFromPipeline=$true, Position=0)]
  [string]$folder,
  
  [Parameter(Mandatory=$false,ValueFromPipeline=$false, Position=1)]
  [string]$city = 'Frankfurt'
)

if ( !(Get-ADOrganizationalUnit -filter { name -eq $city }) )
   { New-ADOrganizationalUnit -Name:$city -ProtectedFromAccidentalDeletion:0 }

$ou = Get-ADOrganizationalUnit -filter { name -eq $city }
$password = ConvertTo-SecureString -String:'Pa$$w0rd' -AsPlainText -Force
$csvfiles = Get-ChildItem -Path:$folder -Filter:*.csv

foreach ($csvfile in $csvfiles) {
 [array]$weltmeister += Import-Csv -Delimiter ';' -Path $csvfile.fullname -Encoding Default 
}

$weltmeister | New-ADUser -Path:$ou -AccountPassword:$password -Enabled:1 -ChangePasswordAtLogon:0